==> nacos-client-2.0.4-sources.jar: com/alibaba/nacos/shaded/com/google/common/util/concurrent/package-info.java <==
/*
 * Copyright (C) 2007 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

/**
 * Concurrency utilities.
 *
 * <p>Commonly used types include {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.ListenableFuture} and
 * {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.Service}.
 *
 * <p>Commonly used utilities include {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.Futures}, {@link
 * com.alibaba.nacos.shaded.com.google.common.util.concurrent.MoreExecutors}, and {@link
 * com.alibaba.nacos.shaded.com.google.common.util.concurrent.ThreadFactoryBuilder}.
 *
 * <p>This package is a part of the open-source <a href="http://github.com.alibaba.nacos.shaded.com.google/guava">Guava</a>
 * library.
 */
@CheckReturnValue
@ParametersAreNonnullByDefault
package com.alibaba.nacos.shaded.com.google.common.util.concurrent;

import com.alibaba.nacos.shaded.com.google.errorprone.annotations.CheckReturnValue;
import javax.annotation.ParametersAreNonnullByDefault;

==> nacos-client-2.2.3-sources.jar: com/alibaba/nacos/shaded/com/google/common/util/concurrent/package-info.java <==
/*
 * Copyright (C) 2007 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

/**
 * Concurrency utilities.
 *
 * <p>Commonly used types include {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.ListenableFuture} and
 * {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.Service}.
 *
 * <p>Commonly used utilities include {@link com.alibaba.nacos.shaded.com.google.common.util.concurrent.Futures}, {@link
 * com.alibaba.nacos.shaded.com.google.common.util.concurrent.MoreExecutors}, and {@link
 * com.alibaba.nacos.shaded.com.google.common.util.concurrent.ThreadFactoryBuilder}.
 *
 * <p>This package is a part of the open-source <a href="http://github.com.alibaba.nacos.shaded.com.google/guava">Guava</a>
 * library.
 */
@CheckReturnValue
@ParametersAreNonnullByDefault
package com.alibaba.nacos.shaded.com.google.common.util.concurrent;

import com.alibaba.nacos.shaded.com.google.errorprone.annotations.CheckReturnValue;
import com.alibaba.nacos.shaded.javax.annotation.ParametersAreNonnullByDefault;
